<?php

namespace B2buy\Policy\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Policy\Http\Requests\PolicyRequest;
use B2buy\Policy\Interfaces\PolicyRepositoryInterface;
use B2buy\Policy\Models\Policy;
use B2buy\Policy\Forms\Policy as Form;

/**
 * APIController  class for policy.
 */
class PolicyAPIController extends BaseController
{

    /**
     * Initialize policy resource controller.
     *
     * @param type PolicyRepositoryInterface $policy
     *
     * @return null
     */
    public function __construct(PolicyRepositoryInterface $policy)
    {
        parent::__construct();
        $this->repository = $policy;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Policy\Repositories\Criteria\PolicyResourceCriteria::class);
    }

    /**
     * Display a list of policy.
     *
     * @return Response
     */
    public function index(PolicyRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Policy\Repositories\Presenter\PolicyPresenter::class)
            ->paginate();
    }

    /**
     * Display policy.
     *
     * @param Request $request
     * @param Model   $policy
     *
     * @return Response
     */
    public function show(PolicyRequest $request, Policy $policy)
    {
        return $policy->setPresenter(\B2buy\Policy\Repositories\Presenter\PolicyListPresenter::class);
        ;
    }

    /**
     * Create new policy.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PolicyRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('policy::policy.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('policy/policy/' . $policy->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('policy/policy');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the policy.
     *
     * @param Request $request
     * @param Model   $policy
     *
     * @return Response
     */
    public function update(PolicyRequest $request, Policy $policy)
    {
        try {
            $data = $request->all();

            $policy->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('policy::policy.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('policy/policy/' . $policy->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('policy/policy/' . $policy->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the policy.
     *
     * @param Model   $policy
     *
     * @return Response
     */
    public function destroy(PolicyRequest $request, Policy $policy)
    {
        try {
            $policy->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('policy::policy.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('policy/policy/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('policy/policy/' . $policy->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
