<?php

namespace B2buy\Policy\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Policy\Models\Policy;

class PolicyPolicy
{

    /**
     * Determine if the given user can view the policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function view(UserPolicy $user, Policy $policy)
    {
        if ($user->canDo('policy.policy.view') && $user->isAdmin()) {
            return true;
        }

        return $policy->user_id == user_id() && $policy->user_type == user_type();
    }

    /**
     * Determine if the given user can create a policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('policy.policy.create');
    }

    /**
     * Determine if the given user can update the given policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function update(UserPolicy $user, Policy $policy)
    {
        if ($user->canDo('policy.policy.edit') && $user->isAdmin()) {
            return true;
        }

        return $policy->user_id == user_id() && $policy->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Policy $policy)
    {
        return $policy->user_id == user_id() && $policy->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Policy $policy)
    {
        if ($user->canDo('policy.policy.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given policy.
     *
     * @param UserPolicy $user
     * @param Policy $policy
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Policy $policy)
    {
        if ($user->canDo('policy.policy.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
