<?php

namespace B2buy\Policy\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Policy\Models\Policy;

class PolicyAction
{
    /**
     * Perform the complete action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */
    public function complete(Policy $policy)
    {
        try {
            $policy->status = 'complete';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */public function verify(Policy $policy)
    {
        try {
            $policy->status = 'verify';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */public function approve(Policy $policy)
    {
        try {
            $policy->status = 'approve';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */public function publish(Policy $policy)
    {
        try {
            $policy->status = 'publish';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */
    public function archive(Policy $policy)
    {
        try {
            $policy->status = 'archive';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Policy $policy
     *
     * @return Policy
     */
    public function unpublish(Policy $policy)
    {
        try {
            $policy->status = 'unpublish';
            return $policy->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
