<?php

namespace B2buy\Policy\Workflow;

use B2buy\Policy\Models\Policy;
use Validator;

class PolicyValidator
{

    /**
     * Determine if the given policy is valid for complete status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function complete(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given policy is valid for verify status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function verify(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given policy is valid for approve status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function approve(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given policy is valid for publish status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function publish(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given policy is valid for archive status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function archive(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given policy is valid for unpublish status.
     *
     * @param Policy $policy
     *
     * @return bool / Validator
     */
    public function unpublish(Policy $policy)
    {
        return Validator::make($policy->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
